@@ -7,6 +7,7 @@ import requests
 
 
 WAIT_SECONDS = 3
+API_VERSION = 'v1'
 
 def _check_for_error(r):
     if not r.ok:
@@ -24,7 +25,7 @@ class Base:
         self.token = token
 
     def _get_route(self):
-        return f'http://{self.host}/v1'
+        return f'{self.host}/{API_VERSION}'
 
     def _get_headers(self):
         return {'Authorization': f'Bearer {self.token}'}
